////////////////////////////////////////////////////////////////
// 検索ボックスガジェット
//   Copyright (C) 2008 - 2012 AAOh inc.
////////////////////////////////////////////////////////////////

/**
 * @fileOverview 検索ボックスガジェット
 * @author       $Author: fujishiro $
 */

(function () {
/**
 * Main。
 *
 * @constructor
 */
searchbox.Main = aaoh.kaze.Gadget.extend(
	aaoh.sora.MainEx, function() {
	this.txtSearch = aaoh.kaze.Gadget.$('txtSearch');
	this.liSuggest = aaoh.kaze.Gadget.$('liSuggest');

	this.suggestTimer      = new aaoh.kaze.Timer(this);
	this.suggestTime       = 20;
	this.tmpKeyward        = null;
	this.flgSelSuggest     = false;
	this.selSuggestMaxSize = 10;
	this.suggestHeight     = 13;
	this.suggestAjax       = new aaoh.kaze.Ajax(this);
	this.suggestJson       = new aaoh.kaze.JSON();

	this.imgAccess    = aaoh.kaze.Gadget.$('imgAccess');
	this.srcAccessNon = 'lib/aaoh.sora.t.png';
	this.srcAccessNow = null;
	this.tipAccessNon = null;
	this.tipAccessNow = null;

	this.tmpKeyInput = null;
	this.tmpTimer    = new aaoh.kaze.Timer(this);

	// yahoo対応
	this.suggestIndex      = -1;
	this.suggestListLength = 0;
	this.itemColor         = '#7f7f7f';
	this.itemBgColor       = '#ffffff';
	this.selFgColor        = '#7f7f7f';

	this.flgGSuggest = false;

	this.mainObj   = aaoh.kaze.Gadget.$('main');
	this.dispTimer = new aaoh.kaze.Timer(this);

	this.reSizeAniSpeed      = 20;
	this.reSizeAniStartValue = { width: 0,  height: 0 };
	this.reSizeAniStopValue  = { width: 0,  height: 0 };
	this.reSizeAniStepValue  = { width: 0,  height: 0 };

	this.reSizeAniStartValue.width = aaoh.sora.App.control.WINDOW_ONDOCK_WIDTH;
	this.reSizeAniStopValue.width  = aaoh.sora.App.control.WINDOW_ONDOCK_WIDTH;
	this.reSizeAniStepValue.height = this.suggestHeight * 3;
	this.reSizeAni = new aaoh.kaze.animation.ResizeAnimation(
		this.mainObj, this.reSizeAniSpeed,
		this.reSizeAniStartValue, this.reSizeAniStopValue, this.reSizeAniStepValue
	);

	this.fadeoutAni = null;
	//if (!aaoh.kaze.Type.isSidebar()) {
	//	this.fadeoutAni = new aaoh.kaze.animation.FadeoutAnimation(this.liSuggest);
	//	this.fadeoutAni.startCallable = function(element, startValue) {
	//		aaoh.kaze.Element.setDisplay(element, true);
	//		aaoh.kaze.Element.setOpacity(element, startValue);
	//	}
	//	this.fadeoutAni.stopCallable = function(element, stopValue) {
	//		aaoh.kaze.Element.setDisplay(element, false);
	//		aaoh.kaze.Element.setOpacity(element, stopValue);
	//		aaoh.sora.App.main.showUnFlyoutAfter();
	//	}
	//}
});
	/**
	 * エスケープした文字列を取得します。
	 *
	 * @param  {String} charset 文字コード
	 * @param  {String} value   エスケープする文字列
	 * @return {String}         エスケープした文字列
	 */
	searchbox.Main.prototype.
	getEscapeValue = function(charset, value) {
		var escapeValue = null;

		switch (charset) {
			case 'shift_jis':
				escapeValue = EscapeSJIS(value);
				break;

			case 'euc-jp':
				escapeValue = EscapeEUCJP(value);
				break;

			case 'jis':
				escapeValue = EscapeJIS8(value);
				break;

			case 'utf-8':
			default:
				escapeValue = EscapeUTF8(value);
				break;
		}

		return escapeValue;
	}

	/**
	 * UTF8の文字を取得します。
	 *
	 * @param  {String} value   エスケープする文字列
	 * @return {String}         エスケープした文字列
	 */
	searchbox.Main.prototype.
	getStringToUTF8 = function(value) {
		var utf8Value = getLatin1ToUTF8(value);

		return utf8Value;
	}

	/**
	 * 検索実行。
	 */
	searchbox.Main.prototype.
	doSearch = function() {
		this.suggestTimer.clearTimeout();

		// 検索キーワードの取得
		var keyward = aaoh.kaze.Element.getValue(this.txtSearch);

		// パラメータの作成
		var param        = null;
		var searchEndine = null;

		// yahoo対応
		if (aaoh.kaze.Type.isYahoo()) {
			var selSearchEngine
				= aaoh.kaze.Gadget.$('selSearchEngine');
			searchEndine = selSearchEngine.data;

		} else {
			for (var cnt = 1; cnt <= 10; cnt++) {
				var selSearchEngine
					= aaoh.kaze.Gadget.$('selSearchEngine_' + cnt);
				var flgSearchEngine
					= aaoh.kaze.Element.isSelected(selSearchEngine);

				if (flgSearchEngine) {
					searchEndine = String(cnt);
					break;
				}
			}
		}

		if (keyward == '') {
			// デフォルトページへ移動
			param = aaoh.sora.App.control.SEARCH_LIST.engine[searchEndine].url;

		} else {
			// 検索ページへ移動
			var charset
				= aaoh.sora.App.control.SEARCH_LIST.engine[searchEndine].charset;
			var value = this.getEscapeValue(charset, keyward);

			param
				= aaoh.sora.App.control.SEARCH_LIST.engine[searchEndine].searchUrl
				+ value;
		}

		// 検索実行
		this.tmpKeyward = null;
		this.showSearch(param);

		// yahoo対応
		if (aaoh.kaze.Type.isYahoo()) {
			this.txtSearch.loseFocus();
		}
		this.tmpKeyInput = keyward;
	}

	/**
	 * サジェスト検索。
	 */
	searchbox.Main.prototype.
	doSuggestSearch = function() {
		// サジェスト検索off
		if (!aaoh.sora.App.model.data.isSuggest) {
			// 何もしない
			return;
		}

		// 対象サジェストURLなし
		var searchEndine = null;

		// yahoo対応
		if (aaoh.kaze.Type.isYahoo()) {
			var selSearchEngine
				= aaoh.kaze.Gadget.$('selSearchEngine');
			searchEndine = selSearchEngine.data;

		} else {
			for (var cnt = 1; cnt <= 10; cnt++) {
				var selSearchEngine
					= aaoh.kaze.Gadget.$('selSearchEngine_' + cnt);
				var flgSearchEngine
					= aaoh.kaze.Element.isSelected(selSearchEngine);

				if (flgSearchEngine) {
					searchEndine = String(cnt);
					break;
				}
			}
		}

		var suggestUrl
			= aaoh.sora.App.control.SEARCH_LIST.engine[searchEndine].suggestUrl;
		if (suggestUrl == null || suggestUrl == '') {
			// 何もしない
			return;
		}

		// 検索キーワードの取得
		var keyward = aaoh.kaze.Element.getValue(this.txtSearch);
		if (keyward == '') {
			// サジェスト表示のクリア
			this.clearSuggest();
			return;
		}

		this.suggestTimer.clearTimeout();
		this.suggestTimer.setTimeout(function() {
			aaoh.sora.App.main.doSuggestSearch2();
		}, this.suggestTime);
	}

	/**
	 * サジェスト検索。
	 */
	searchbox.Main.prototype.
	doSuggestSearch2 = function() {
		this.suggestTimer.clearTimeout();

		var keyward = aaoh.kaze.Element.getValue(this.txtSearch);
		if (
			keyward == ''
			|| (this.tmpKeyward != null && this.tmpKeyward == keyward)
		) {
			// 何もしない
			return;
		}

		// パラメータの作成
		var searchEndine = null;

		// yahoo対応
		if (aaoh.kaze.Type.isYahoo()) {
			var selSearchEngine
				= aaoh.kaze.Gadget.$('selSearchEngine');
			searchEndine = selSearchEngine.data;

		} else {
			for (var cnt = 1; cnt <= 10; cnt++) {
				var selSearchEngine
					= aaoh.kaze.Gadget.$('selSearchEngine_' + cnt);
				var flgSearchEngine
					= aaoh.kaze.Element.isSelected(selSearchEngine);

				if (flgSearchEngine) {
					searchEndine = String(cnt);
					break;
				}
			}
		}

		var suggestUrl
			= aaoh.sora.App.control.SEARCH_LIST.engine[searchEndine].suggestUrl;
		var charset
			= aaoh.sora.App.control.SEARCH_LIST.engine[searchEndine].charset;
		var value = this.getEscapeValue(charset, keyward);
		var param = suggestUrl + value;

		// サジェスト検索実行
		this.doUpdateSuggest(param);
	}

	/**
	 * サジェスト表示のクリア。
	 */
	searchbox.Main.prototype.
	clearSuggest = function() {
		this.tmpKeyward = null;

		// サジェスト検索off
		if (!aaoh.sora.App.model.data.isSuggest) {
			// 何もしない
			return;
		}

		// サジェスト表示のクリア
		this.showUnFlyout();
	}

	/**
	 * サジェスト表示。
	 *
	 * @param {Object} suggestList サジェストデータ
	 */
	searchbox.Main.prototype.
	showSuggest = function(suggestList) {
		// 検索キーワードの取得
		var keyward = aaoh.kaze.Element.getValue(this.txtSearch);
		if (
			keyward == ''
			|| (this.tmpKeyward != null && this.tmpKeyward == keyward)
		) {
			// 何もしない
			this.showSuggestNone();
			return;
		}

		// 更新イメージを戻す
		aaoh.kaze.Element.setImage(this.imgAccess,   this.srcAccessNon);
		aaoh.kaze.Element.setTooltip(this.imgAccess, this.tipAccessNon);

		// サジェスト初期化
		var selSuggest = aaoh.kaze.Gadget.$('selSuggest');
		var len        = selSuggest.length;
		if (aaoh.kaze.Type.isGoogle()) {
			// google対応
			selSuggest.removeAllElements();

		// yahoo対応
		} else if (aaoh.kaze.Type.isYahoo()) {
			for (var cnt = 0; cnt < this.selSuggestMaxSize; cnt++) {
				var item = selSuggest.getElementById('selSuggest' + (cnt + 1));
				if (item == null) {
					break;
				}

				item.data = '';
			}

		} else {
			for (var cnt = 0; cnt < len; cnt++) {
				selSuggest.remove(0);
			}
		}

		// yahoo対応
		if (aaoh.kaze.Type.isYahoo()) {
			this.suggestListLength
				= Math.min(this.selSuggestMaxSize, suggestList.length);

		} else {
			this.suggestListLength = suggestList.length;
		}

		// サジェスト追加
		for(var cnt = 0; cnt < this.suggestListLength; cnt++) {
			if (aaoh.kaze.Type.isGoogle()) {
				// google対応
				var value     = suggestList[cnt];
				var optionObj = selSuggest.appendString(value);

				selSuggest.children.item(cnt).children.item(0).color
					= this.itemColor;

			// yahoo対応
			} else if (aaoh.kaze.Type.isYahoo()) {
				// 文字コードの変換
				var value = this.getStringToUTF8(suggestList[cnt]);
				var item  = selSuggest.getElementById('selSuggest' + (cnt + 1));
				if (item == null) {
					break;
				}

				item.data = value;
				item.style.color           = this.itemColor;
				item.style.backgroundColor = this.itemBgColor;
				item.onMouseEnter = function() {
					this.style.color           = aaoh.sora.App.main.itemBgColor;
					this.style.backgroundColor = aaoh.sora.App.main.itemColor;
				};
				item.onMouseExit  = function() {
					this.style.color           = aaoh.sora.App.main.itemColor;
					this.style.backgroundColor = aaoh.sora.App.main.itemBgColor;
				};

			} else {
				var optionObj = document.createElement('option');
				var value     = suggestList[cnt];
				optionObj.innerHTML = value;
				optionObj.value     = value;
				selSuggest.appendChild(optionObj);
			}
		}

		if (aaoh.kaze.Type.isGoogle()) {
			// google対応
			selSuggest.height
				= Math.min(this.selSuggestMaxSize, suggestList.length)
				* (this.suggestHeight + 1);

			var selSuggestBottom = aaoh.kaze.Gadget.$('selSuggestBottom');
			var selSuggestLeft   = aaoh.kaze.Gadget.$('selSuggestLeft');
			var selSuggestRight  = aaoh.kaze.Gadget.$('selSuggestRight');
			selSuggestBottom.y     = selSuggest.height - 3;
			selSuggestLeft.height  = selSuggest.height + 2;
			selSuggestRight.height = selSuggest.height + 2;

		// yahoo対応
		} else if (aaoh.kaze.Type.isYahoo()) {
			selSuggest.height
				= Math.min(this.selSuggestMaxSize, suggestList.length)
				* this.suggestHeight;

			var selSuggestBottom = aaoh.kaze.Gadget.$('selSuggestBottom');
			var selSuggestLeft   = aaoh.kaze.Gadget.$('selSuggestLeft');
			var selSuggestRight  = aaoh.kaze.Gadget.$('selSuggestRight');
			selSuggestBottom.vOffset = selSuggest.height + 1;
			selSuggestLeft.height    = selSuggest.height + 2;
			selSuggestRight.height   = selSuggest.height + 2;

		} else {
			selSuggest.size = Math.min(this.selSuggestMaxSize, suggestList.length);
		}

		// サジェスト表示
		this.showOnFlyout();
	}

	/**
	 * サジェスト検索。
	 */
	searchbox.Main.prototype.
	showSuggestNone = function() {
		// 更新イメージを戻す
		aaoh.kaze.Element.setImage(this.imgAccess,   this.srcAccessNon);
		aaoh.kaze.Element.setTooltip(this.imgAccess, this.tipAccessNon);

		this.clearSuggest();
	}

	/**
	 * サジェスト検索。
	 *
	 * @param {String} param 検索パラメータ
	 */
	searchbox.Main.prototype.
	doUpdateSuggest = function(param) {
		// 更新イメージをチェック中にする
		aaoh.kaze.Element.setImage(this.imgAccess,   this.srcAccessNow);
		aaoh.kaze.Element.setTooltip(this.imgAccess, this.tipAccessNow);

		try {
			this.suggestAjax.gets(param, function(resTxt) {
				aaoh.sora.App.main.showUpdateSuggest(resTxt);
			});
		} catch(ex) {
			this.updateSuggestError(ex);
		}
	}

	/**
	 * サジェスト表示。
	 *
	 * @param {String} resTxt レスポンスオブジェクト
	 */
	searchbox.Main.prototype.
	showUpdateSuggest = function(resTxt) {
		// 更新チェックデータの取得
		var updData = null;
		if (resTxt != null) {
			try {
				updData = this.suggestJson.parse(resTxt);

			} catch(ex) {
				this.updateSuggestException(ex);
				return;
			}
		}

		// 結果取得失敗
		if (updData == null || updData.length < 2) {
			// 更新イメージを元に戻す
			this.showSuggestNone();
			return;
		}

		// 対象サジェスト取得なし
		var targetKeyward = updData[0];
		var suggestList   = updData[1];
		if (suggestList == null || suggestList <= 0) {
			// 更新イメージを元に戻す
			this.showSuggestNone();
			return;
		}

		// サジェスト表示
		this.showSuggest(suggestList);

		var keyward = aaoh.kaze.Element.getValue(this.txtSearch);
		this.tmpKeyward = keyward;
	}

	/**
	 * Ajaxエラー。
	 *
	 * @param {Object} res レスポンスオブジェクト
	 */
	searchbox.Main.prototype.
	updateSuggestError = function(res) {
		this.showSuggestNone();
	}

	/**
	 * Ajaxエラー。
	 *
	 * @param {Object} ex エラーオブジェクト
	 */
	searchbox.Main.prototype.
	updateSuggestException = function(ex) {
		this.showSuggestNone();
	}

	/**
	 * 検索入力(確定前)。
	 *
	 * @param {Object} event イベント
	 */
	searchbox.Main.prototype.
	doInputSearchBefore = function(event) {
		if (event == null) {
			event = aaoh.kaze.Gadget.getEvent();
		}
		var key = event.keyCode;

		// Altが押されている
		if (event.altKey) {
			// 処理続行
		}

		// コントロールが押されている
		if (event.ctrlKey) {
			// 処理続行
		}

		// シフトが押されている
		if (event.shiftKey) {
			// 処理続行
		}

		switch(key) {
			// エスケープ、左右キー
			case 27:
			case 39:
			case 37:
				// 検索ボックスへフォーカスを移す
				this.clearSuggest();

				aaoh.kaze.Element.setFocus(this.txtSearch);
				break;

			// 上キー
			case 38:
				// サジェスト検索ボックスの先頭へフォーカスを移す
				var selSuggest = aaoh.kaze.Gadget.$('selSuggest');
				var flgDisp    = aaoh.kaze.Element.isDisplay(this.liSuggest);
				if (flgDisp) {
					this.flgSelSuggest = true;

					// google対応
					if (aaoh.kaze.Type.isGoogle()) {
						aaoh.sora.App.main.flgGSuggest = true;
						if (selSuggest.selectedIndex <= -1) {
							selSuggest.selectedIndex = selSuggest.children.count - 1;
						} else {
							selSuggest.selectedIndex = selSuggest.selectedIndex - 1;
						}

					// yahoo対応
					} else if (aaoh.kaze.Type.isYahoo()) {
						if (this.suggestIndex <= -1) {
							this.txtSearch.loseFocus();

							var itemIndex = selSuggest.childNodes.length - 1;
							var item      = selSuggest.childNodes.item(itemIndex);
							item.style.color           = this.itemBgColor;
							item.style.backgroundColor = this.itemColor;
							this.suggestIndex = itemIndex;
						}

					} else {
						if (selSuggest.selectedIndex <= -1) {
							selSuggest.selectedIndex = selSuggest.length - 1;
							aaoh.kaze.Element.setFocus(selSuggest);
						}
					}
				} // if (flgDisp)
				break;

			// 下キー
			case 40:
				// サジェスト検索ボックスの最後へフォーカスを移す
				var selSuggest = aaoh.kaze.Gadget.$('selSuggest');
				var flgDisp    = aaoh.kaze.Element.isDisplay(this.liSuggest);
				if (flgDisp) {
					this.flgSelSuggest = true;

					// google対応
					if (aaoh.kaze.Type.isGoogle()) {
						aaoh.sora.App.main.flgGSuggest = true;
						if (selSuggest.selectedIndex <= -1) {
							selSuggest.selectedIndex = 0;
						} else {
							selSuggest.selectedIndex = selSuggest.selectedIndex + 1;
						}

					// yahoo対応
					} else if (aaoh.kaze.Type.isYahoo()) {
						if (this.suggestIndex <= -1) {
							this.txtSearch.loseFocus();

							var itemIndex = 0;
							var item      = selSuggest.childNodes.item(itemIndex);
							item.style.color           = this.itemBgColor;
							item.style.backgroundColor = this.itemColor;
							this.suggestIndex = itemIndex;
						}

					} else {
						if (selSuggest.selectedIndex <= -1) {
							selSuggest.selectedIndex = 0;
							aaoh.kaze.Element.setFocus(selSuggest);
						}
					}
				} // if (flgDisp)
				break;

			// エンター
			case 13:
			default:
				break;
		} // switch(key)
	}

	/**
	 * 検索入力(確定後)。
	 *
	 * @param {Object} event イベント
	 */
	searchbox.Main.prototype.
	doInputSearchAfter = function(event) {
		if (event == null) {
			event = aaoh.kaze.Gadget.getEvent();
		}
		var key = event.keyCode;

		// Altが押されている
		if (event.altKey) {
			// 処理続行
		}

		// コントロールが押されている
		if (event.ctrlKey) {
			// 処理続行
		}

		// シフトが押されている
		if (event.shiftKey) {
			// 処理続行
		}

		switch(key) {
			// エスケープ、左右キー
			case 27:
			case 39:
			case 37:
			// google対応
			// yahoo対応
			// エンター、上下キー
			//case 13:
			case 65:
				// 何もしない
				break;

			// エンター、上下キー
			case 13:
				// google対応
				// yahoo対応
				if (
					aaoh.kaze.Type.isGoogle() || aaoh.kaze.Type.isYahoo()
				) {
					// 何もしない
					break;
				}
			case 38:
			case 40:
			default:
				// サジェスト検索
				this.doSuggestSearch();
				break;
		} // switch(key)
	}

	/**
	 * 検索入力(確定後)。
	 *
	 * @param {Object} event イベント
	 */
	searchbox.Main.prototype.
	doInputSearchAfter2 = function(event) {
		if (event == null) {
			event = aaoh.kaze.Gadget.getEvent();
		}
		var key = event.keyCode;

		// Altが押されている
		if (event.altKey) {
			// 処理続行
		}

		// コントロールが押されている
		if (event.ctrlKey) {
			// 処理続行
		}

		// シフトが押されている
		if (event.shiftKey) {
			// 処理続行
		}

		switch(key) {
			// エンター
			case 13:
				// google対応
				if (aaoh.kaze.Type.isGoogle()) {
					var selSuggest = aaoh.kaze.Gadget.$('selSuggest');
					if (selSuggest.selectedIndex <= -1) {
						this.clearSuggest();
						this.doSearch();

					} else {
						this.doSuggestSelect(event);
					}

				// yahoo対応
				} else if (aaoh.kaze.Type.isYahoo()) {
					this.txtSearch.data = this.txtSearch.data.replace('\n', '');

					if (this.suggestIndex <= -1) {
						this.clearSuggest();
						this.doSearch();

					} else {
						this.txtSearch.rejectKeyPress();
					}

				} else {
					this.clearSuggest();
					this.doSearch();
				}
				break;

			// 上下キー
			// エスケープ、左右キー
			case 27:
			case 39:
			case 37:
			case 38:
			case 40:
			default:
				break;
		} // switch(key)
	}

	/**
	 * サジェスト検索入力(確定前)。
	 *
	 * @param {Object} event イベント
	 */
	searchbox.Main.prototype.
	doInputSuggestBefore = function(event) {
		if (event == null) {
			event = aaoh.kaze.Gadget.getEvent();
		}
		var key = event.keyCode;

		// yahoo対応
		if (aaoh.kaze.Type.isYahoo()) {
			if (!this.liSuggest.visible) {
				return;
			}
		}

		// Altが押されている
		if (event.altKey) {
			// 処理続行
		}

		// コントロールが押されている
		if (event.ctrlKey) {
			// 処理続行
		}

		// シフトが押されている
		if (event.shiftKey) {
			// 処理続行
		}

		switch(key) {
			// エスケープ、左右キー
			case 27:
			case 39:
			case 37:
				// 検索ボックスへフォーカスを移す
				this.clearSuggest();

				aaoh.kaze.Element.setFocus(this.txtSearch);
				break;

			// 上キー
			case 38:
				// 検索ボックスへフォーカスを移す
				var selSuggest = aaoh.kaze.Gadget.$('selSuggest');
				var flgDisp    = aaoh.kaze.Element.isDisplay(this.liSuggest);
				if (flgDisp) {
					// google対応
					if (aaoh.kaze.Type.isGoogle()) {
						if (selSuggest.selectedIndex == 0) {
							selSuggest.selectedIndex = -1;

							aaoh.kaze.Element.setFocus(this.txtSearch);
						}

					// yahoo対応
					} else if (aaoh.kaze.Type.isYahoo()) {
						if (this.suggestIndex == 0) {
							var preItem = selSuggest.childNodes.item(this.suggestIndex);
							preItem.style.color           = this.itemColor;
							preItem.style.backgroundColor = this.itemBgColor;

							aaoh.kaze.Element.setFocus(this.txtSearch);
							this.suggestIndex = -1;

						} else {
							var preItem = selSuggest.childNodes.item(this.suggestIndex);
							preItem.style.color           = this.itemColor;
							preItem.style.backgroundColor = this.itemBgColor;

							var itemIndex = this.suggestIndex - 1;
							var item      = selSuggest.childNodes.item(itemIndex);
							item.style.color           = this.itemBgColor;
							item.style.backgroundColor = this.itemColor;
							this.suggestIndex = itemIndex;
						}

					} else {
						if (selSuggest.selectedIndex == 0) {
							aaoh.kaze.Element.setFocus(this.txtSearch);
						}
					}
				} // if (flgDisp)
				break;

			// 下キー
			case 40:
				// サジェスト検索ボックスの最後へフォーカスを移す
				var selSuggest = aaoh.kaze.Gadget.$('selSuggest');
				var flgDisp    = aaoh.kaze.Element.isDisplay(this.liSuggest);
				if (flgDisp) {
					// google対応
					if (aaoh.kaze.Type.isGoogle()) {
						if (
							selSuggest.selectedIndex == (selSuggest.children.count - 1)
						) {
							selSuggest.selectedIndex = -1;
							aaoh.kaze.Element.setFocus(this.txtSearch);
						}

					// yahoo対応
					} else if (aaoh.kaze.Type.isYahoo()) {
						if (this.suggestIndex == (this.suggestListLength - 1)) {
							var preItem = selSuggest.childNodes.item(this.suggestIndex);
							preItem.style.color           = this.itemColor;
							preItem.style.backgroundColor = this.itemBgColor;

							aaoh.kaze.Element.setFocus(this.txtSearch);
							this.suggestIndex = -1;

						} else {
							var preItem = selSuggest.childNodes.item(this.suggestIndex);
							preItem.style.color           = this.itemColor;
							preItem.style.backgroundColor = this.itemBgColor;

							var itemIndex = this.suggestIndex + 1;
							var item      = selSuggest.childNodes.item(itemIndex);
							item.style.color           = this.itemBgColor;
							item.style.backgroundColor = this.itemColor;
							this.suggestIndex = itemIndex;
						}

					} else {
						if (selSuggest.selectedIndex == (selSuggest.length - 1)) {
							aaoh.kaze.Element.setFocus(this.txtSearch);
						}
					}
				} // if (flgDisp)
				break;

			// エンター
			case 13:
			default:
				break;
		} // switch(key)
	}

	/**
	 * サジェスト検索入力(確定後)。
	 *
	 * @param {Object} event イベント
	 */
	searchbox.Main.prototype.
	doInputSuggestAfter = function(event) {
		if (event == null) {
			event = aaoh.kaze.Gadget.getEvent();
		}
		var key = event.keyCode;

		// yahoo対応
		if (aaoh.kaze.Type.isYahoo()) {
			if (!this.liSuggest.visible) {
				return;
			}
		}

		// Altが押されている
		if (event.altKey) {
			// 処理続行
		}

		// コントロールが押されている
		if (event.ctrlKey) {
			// 処理続行
		}

		// シフトが押されている
		if (event.shiftKey) {
			// 処理続行
		}

		switch(key) {
			// エスケープ、上下左右キー
			case 27:
			case 39:
			case 37:
			case 38:
			case 40:
				// 何もしない
				break;

			// エンター
			case 13:
				// yahoo対応
				if (aaoh.kaze.Type.isYahoo()) {
					var selSuggest = aaoh.kaze.Gadget.$('selSuggest');
					var item       = selSuggest.childNodes.item(this.suggestIndex);
					var popupValue = item.data;
					this.doSuggestSelect(event, popupValue);

				} else {
					this.doSuggestSelect(event);
				}
				break;

			default:
				break;
		} // switch(key)
	}

	/**
	 * サジェスト検索選択。
	 *
	 * @param {Object} event      イベント
	 * @param {String} popupValue 選択値(yahoo対応)
	 */
	searchbox.Main.prototype.
	doSuggestSelect = function(event, popupValue) {
		// サジェストキーワードの設定
		var keyward = null;

		// google対応
		if (aaoh.kaze.Type.isGoogle()) {
			var selSuggest = aaoh.kaze.Gadget.$('selSuggest');
			if (selSuggest.selectedItem == null) {
				return;
			}
			keyward = selSuggest.selectedItem.children.item(0).innerText;

		// yahoo対応
		} else if (aaoh.kaze.Type.isYahoo()) {
			keyward = popupValue;

		} else {
			if (event == null) {
				event = aaoh.kaze.Gadget.getEvent();
			}

			if (event.srcElement != null) {
				keyward = event.srcElement.value;

			} else if (event.target != null) {
				keyward = event.target.value;
			}
		}
		aaoh.kaze.Element.setValue(this.txtSearch, keyward);

		// 検索ボックスへフォーカスを移す
		this.clearSuggest();

		// 検索実行
		this.doSearch();
	}

	/**
	 * 検索エンジンの選択。
	 *
	 * @param popupValue 選択値(yahoo対応)
	 */
	searchbox.Main.prototype.
	setSearchEngine = function(popupValue) {
		var imgSrc = null;

		// yahoo対応
		if (aaoh.kaze.Type.isYahoo()) {
			var selSearchEngine
				= aaoh.kaze.Gadget.$('selSearchEngine');
			var txtSearchEngine
				= aaoh.kaze.Gadget.$('txtSearchEngine');
			selSearchEngine.data = popupValue;
			txtSearchEngine.data
				= aaoh.sora.App.control.SEARCH_LIST.engine[popupValue].dispName;

			this.txtSearch.data = this.txtSearch.data.replace('\n', '');
			imgSrc = popupValue;

		} else {
			for (var cnt = 1; cnt <= 10; cnt++) {
				var selSearchEngine
					= aaoh.kaze.Gadget.$('selSearchEngine_' + cnt);
				var flgSearchEngine
					= aaoh.kaze.Element.isSelected(selSearchEngine);

				if (flgSearchEngine) {
					imgSrc = String(cnt);
					break;
				}
			}
		}

		var imgSearchEngine = aaoh.kaze.Gadget.$('imgSearchEngine');
		var msgSearchEngine
			= aaoh.sora.App.control.locale.getString('MSG_SEARCH_ENGINE');
		var tooltip
			= aaoh.sora.App.control.SEARCH_LIST.engine[imgSrc].dispName
			+ msgSearchEngine;
		aaoh.kaze.Element.setImage(
			imgSearchEngine,
			aaoh.sora.App.control.SEARCH_LIST.engine[imgSrc].icon
		);
		aaoh.kaze.Element.setTooltip(imgSearchEngine, tooltip);

		// 検索ボックスをオンフォーカスにする
		this.setSuggestBlur();
		aaoh.kaze.Element.setFocus(this.txtSearch);
		aaoh.kaze.Element.setTextSelect(this.txtSearch);
	}

	/**
	 * 検索ボックスのオンフォーカス。
	 */
	searchbox.Main.prototype.
	setSearchFocus = function() {
		this.initOnFlyout();
	}

	/**
	 * 検索ボックスのオフフォーカス。
	 */
	searchbox.Main.prototype.
	setSearchBlur = function() {
		// 何もしない
	}

	/**
	 * サジェスト検索ボックスのオンフォーカス。
	 */
	searchbox.Main.prototype.
	setSuggestFocus = function() {
		this.flgSelSuggest = true;
	}

	/**
	 * サジェスト検索ボックスのオフフォーカス。
	 */
	searchbox.Main.prototype.
	setSuggestBlur = function() {
		this.flgSelSuggest = false;

		// サジェスト表示のクリア
		this.clearSuggest();
	}

	/**
	 * 検索エンジン選択。
	 */
	searchbox.Main.prototype.
	doPopupSearchEngine = function() {
		if (!aaoh.kaze.Type.isYahoo()) {
			return;
		}

		// yahoo対応
		var itemList        = new Array();
		var selSearchEngine = aaoh.kaze.Gadget.$('selSearchEngine');
		var main            = aaoh.kaze.Gadget.$('main');

		for (var cnt = 1; cnt <= 10; cnt++) {
			var name = String(cnt);

			var item = new MenuItem();
			item.title
				= aaoh.sora.App.control.SEARCH_LIST.engine[name].dispName;
			if (selSearchEngine.data == name) {
				item.checked = true;
			} else {
				item.checked = false;
			}

			itemList.push(item);
		}

		itemList[0].onSelect = function() {
			aaoh.sora.App.main.setSearchEngine('1');
		};
		itemList[1].onSelect = function() {
			aaoh.sora.App.main.setSearchEngine('2');
		};
		itemList[2].onSelect = function() {
			aaoh.sora.App.main.setSearchEngine('3');
		};
		itemList[3].onSelect = function() {
			aaoh.sora.App.main.setSearchEngine('4');
		};
		itemList[4].onSelect = function() {
			aaoh.sora.App.main.setSearchEngine('5');
		};
		itemList[5].onSelect = function() {
			aaoh.sora.App.main.setSearchEngine('6');
		};
		itemList[6].onSelect = function() {
			aaoh.sora.App.main.setSearchEngine('7');
		};
		itemList[7].onSelect = function() {
			aaoh.sora.App.main.setSearchEngine('8');
		};
		itemList[8].onSelect = function() {
			aaoh.sora.App.main.setSearchEngine('9');
		};
		itemList[9].onSelect = function() {
			aaoh.sora.App.main.setSearchEngine('10');
		};

		var popupX = main.hOffset + selSearchEngine.hOffset - 17;
		var popupY = main.vOffset + selSearchEngine.vOffset + 5;
		popupMenu(itemList, popupX, popupY);
	}

	/**
	 * サジェスト表示。
	 */
	searchbox.Main.prototype.
	initOnFlyout = function() {
		// 何もしない
	}

	/**
	 * サジェスト表示。
	 */
	searchbox.Main.prototype.
	showOnFlyout = function() {
		// opera widget対応
		var selSuggest = aaoh.kaze.Gadget.$('selSuggest');

		// opera widget対応
		var width  = aaoh.sora.App.control.WINDOW_ONDOCK_WIDTH;
		var height = null;
		// google対応
		if (aaoh.kaze.Type.isGoogle()) {
			height = aaoh.sora.App.control.WINDOW_ONDOCK_HEIGHT
				+ ((this.suggestHeight + 1) * selSuggest.children.count) - 10;

		// yahoo対応
		} else if (aaoh.kaze.Type.isYahoo()) {
			height = aaoh.sora.App.control.WINDOW_ONDOCK_HEIGHT
				+ (this.suggestHeight * selSuggest.childNodes.length) - 10;

		} else {
			height = aaoh.sora.App.control.WINDOW_ONDOCK_HEIGHT
				+ (this.suggestHeight * (selSuggest.size + 2));
		}

		// サジェスト表示のサイズ調整
		if (aaoh.kaze.Type.isGoogle()) {
			// google対応
			aaoh.kaze.Gadget.setSize(width - 2, height - 2);

		} else if (aaoh.kaze.Type.isYahoo()) {
			// yahoo対応
			var indexObj = aaoh.kaze.Gadget.$('index');
			aaoh.kaze.Element.setSize(indexObj, width, height);

		} else {
			aaoh.kaze.Gadget.setSize(width, height);
		}
		//aaoh.kaze.Element.setSize(this.mainObj, width, height);
		this.reSizeAniStartValue.height = aaoh.sora.App.control.WINDOW_ONDOCK_HEIGHT;
		this.reSizeAniStopValue.height  = height;
		this.reSizeAni.start();

		if (aaoh.kaze.Type.isSidebar()) {
			var sidebarImgBg = aaoh.kaze.Gadget.$('sidebarImgBg');
			sidebarImgBg.height = aaoh.sora.App.control.WINDOW_ONDOCK_HEIGHT;
		}

		// サジェスト表示
		aaoh.kaze.Element.setDisplay(this.liSuggest, true);

		// yahoo対応
		if (aaoh.kaze.Type.isYahoo()) {
			aaoh.kaze.Element.setFocus(this.txtSearch);
			this.suggestIndex = -1;
		}
	}

	/**
	 * サジェスト表示のクリア。
	 */
	searchbox.Main.prototype.
	showUnFlyout = function() {
		var flgDisp = aaoh.kaze.Element.isDisplay(this.liSuggest);
		if (!flgDisp) {
			// 何もしない
			return;
		}

		// サジェスト表示のクリア
		//aaoh.kaze.Element.setDisplay(this.liSuggest, false);
		if (this.fadeoutAni != null) {
			this.fadeoutAni.start();

		} else {
			aaoh.kaze.Element.setDisplay(this.liSuggest, false);
			this.showUnFlyoutAfter();
		}
	}

	/**
	 * サジェスト表示のクリア。
	 */
	searchbox.Main.prototype.
	showUnFlyoutAfter = function() {
		// サジェスト表示のサイズ調整
		if (aaoh.kaze.Type.isGoogle()) {
			// google対応
			aaoh.kaze.Element.setSize(
				this.mainObj,
				aaoh.sora.App.control.WINDOW_ONDOCK_WIDTH - 2,
				aaoh.sora.App.control.WINDOW_ONDOCK_HEIGHT - 12 - 2
			);

		} else {
			aaoh.kaze.Element.setSize(
				this.mainObj,
				aaoh.sora.App.control.WINDOW_ONDOCK_WIDTH,
				aaoh.sora.App.control.WINDOW_ONDOCK_HEIGHT - 12
			);
		}

		if (aaoh.kaze.Type.isYahoo()) {
			// yahoo対応
			var indexObj = aaoh.kaze.Gadget.$('index');
			aaoh.kaze.Element.setSize(
				indexObj,
				aaoh.sora.App.control.WINDOW_ONDOCK_WIDTH,
				aaoh.sora.App.control.WINDOW_ONDOCK_HEIGHT
			);

		} else {
			aaoh.kaze.Gadget.setSize(
				aaoh.sora.App.control.WINDOW_ONDOCK_WIDTH,
				aaoh.sora.App.control.WINDOW_ONDOCK_HEIGHT
			);
		}

		if (aaoh.kaze.Type.isSidebar()) {
			var sidebarImgBg = aaoh.kaze.Gadget.$('sidebarImgBg');
			sidebarImgBg.opacity = 0;

			this.dispTimer.setTimeout(function() {
				var sidebarImgBg = aaoh.kaze.Gadget.$('sidebarImgBg');
				sidebarImgBg.opacity = 100;
			}, 100);
		}

		// google対応
		if (aaoh.kaze.Type.isGoogle()) {
			var selSuggest = aaoh.kaze.Gadget.$('selSuggest');
			selSuggest.selectedIndex = -1;

		// yahoo対応
		} else if (aaoh.kaze.Type.isYahoo()) {
			this.suggestIndex = -1;
		}
	}

	/**
	 * 検索実行。
	 *
	 * @param {String} param 検索パラメータ
	 */
	searchbox.Main.prototype.
	showSearch = function(param) {
		if (aaoh.kaze.Type.isOpera()) {
			// opera widget対応
			var keyward = aaoh.kaze.Element.getValue(this.txtSearch);
			this.tmpKeyInput = keyward;
		}

		aaoh.kaze.Gadget.openURL(param);
	}

	/**
	 * キー入力監視。
	 */
	searchbox.Main.prototype.
	checkKeyInput = function() {
		var keyward = aaoh.kaze.Element.getValue(this.txtSearch);
		if (this.tmpKeyInput == null || this.tmpKeyInput != keyward) {
			this.tmpKeyInput = keyward;
			this.doSuggestSearch();
		}
	}

	/**
	 * フォーカス設定。
	 */
	searchbox.Main.prototype.
	setFocus = function() {
		// ボタンが連打できないようにする
		aaoh.kaze.Element.setFocus(this.txtSearch);
	}

	/**
	 * 表示データの初期化。
	 */
	searchbox.Main.prototype.
	initData = function() {
		//var flgOnDock = aaoh.sora.App.control.flgOnDock;
		var type      = aaoh.sora.App.model.data.type;

		this.initToolbarData(type);

		// google対応
		var main = null;
		if (aaoh.kaze.Type.isGoogle()) {
			main = aaoh.kaze.Gadget.$('googleMain');

		} else {
			main = aaoh.kaze.Gadget.$('main');
		}

		var srcMain = null;
		if (aaoh.kaze.Type.isSidebar()) {
			srcMain = 'lib/aaoh.sora.t.png';

		} else {
			srcMain = 'images/searchbox' + type + '-base.png';
		}
		// IE6では入れ子透過PNG対応しない
		aaoh.kaze.Element.setBackgroundImage(main, srcMain, false);

		// 透過PNG対応
		if (aaoh.kaze.Type.isSidebar()) {
			var sidebarImgBg    = aaoh.kaze.Gadget.$('sidebarImgBg');
			var srcSidebarImgBg = 'images/searchbox' + type + '-base_sidebar.png';
			aaoh.kaze.Element.setImage(sidebarImgBg, srcSidebarImgBg);
		}

		this.srcAccessNow = 'images/searchbox' + type + '-load.png';
		this.tipAccessNon
			= aaoh.sora.App.control.locale.getString('TIP_ACCESS_NON');
		this.tipAccessNow
			= aaoh.sora.App.control.locale.getString('TIP_ACCESS_NOW');

		var imgSrc = aaoh.sora.App.model.data.searchEngineDef;
		var imgSearchEngine = aaoh.kaze.Gadget.$('imgSearchEngine');
		var msgSearchEngine
			= aaoh.sora.App.control.locale.getString('MSG_SEARCH_ENGINE');
		var tooltip
			= aaoh.sora.App.control.SEARCH_LIST.engine[imgSrc].dispName
			+ msgSearchEngine;
		aaoh.kaze.Element.setImage(
			imgSearchEngine,
			aaoh.sora.App.control.SEARCH_LIST.engine[imgSrc].icon
		);
		aaoh.kaze.Element.setTooltip(imgSearchEngine, tooltip);

		// yahoo対応
		if (aaoh.kaze.Type.isYahoo()) {
			var popupValue = aaoh.sora.App.model.data.searchEngineDef;

			var fgColor     = null;
			switch (type) {
				default:
				case '1':
					fgColor     = '#7f7f7f';
					break;

				case '2':
					fgColor     = '#ffffff';
					break;

				case '3':
					fgColor     = '#ffffff';
					break;
			}
			this.selFgColor = fgColor;

			var selSearchEngine
				= aaoh.kaze.Gadget.$('selSearchEngine');
			var txtSearchEngine
				= aaoh.kaze.Gadget.$('txtSearchEngine');
			selSearchEngine.data = popupValue;
			txtSearchEngine.data
				= aaoh.sora.App.control.SEARCH_LIST.engine[popupValue].dispName;
			txtSearchEngine.style.color = this.selFgColor;

			this.txtSearch.data = this.txtSearch.data.replace('\n', '');
			this.txtSearch.loseFocus();

		} else {
			var selSearchEngine = aaoh.kaze.Gadget.$(
				'selSearchEngine_' + aaoh.sora.App.model.data.searchEngineDef
			)
			aaoh.kaze.Element.setSelected(selSearchEngine, true);
		}

		this.initSearchboxData(type);

		this.clearSuggest();
		//this.dispTimer.setTimeout(function() {
		//	aaoh.sora.App.main.setFocus();
		//}, 200);
	}

	/**
	 * 表示データの初期化。
	 *
	 * @param {String} type 表示タイプ
	 */
	searchbox.Main.prototype.
	initToolbarData = function(type) {
		var btnOption = aaoh.kaze.Gadget.$('btnOption');
		var btnClose  = aaoh.kaze.Gadget.$('btnClose');
		if (btnOption == null || btnClose == null) {
			return;
		}

		var srcBtnOptionUp   = null;
		var srcBtnOptionOver = null;
		var srcBtnOptionDown = null;
		var srcBtnCloseUp    = null;
		var srcBtnCloseOver  = null;
		var srcBtnCloseDown  = null;
		if (!aaoh.kaze.Type.isGoogle() && !aaoh.kaze.Type.isIE()) {
			srcBtnOptionUp = 'images/searchbox' + type + '-option.png';
			srcBtnCloseUp  = 'images/searchbox' + type + '-close.png';

		} else {
			srcBtnOptionUp = 'sub-images/searchbox' + type + '-option_up.png';
			srcBtnCloseUp  = 'sub-images/searchbox' + type + '-close_up.png';
		}
		srcBtnOptionOver = 'sub-images/searchbox' + type + '-option_over.png';
		srcBtnOptionDown = 'sub-images/searchbox' + type + '-option_down.png';
		srcBtnCloseOver  = 'sub-images/searchbox' + type + '-close_over.png';
		srcBtnCloseDown  = 'sub-images/searchbox' + type + '-close_down.png';

		aaoh.kaze.Element.setBackgroundImage(
			btnOption, srcBtnOptionUp, srcBtnOptionOver, srcBtnOptionDown
		);
		aaoh.kaze.Element.setBackgroundImage(
			btnClose, srcBtnCloseUp, srcBtnCloseOver, srcBtnCloseDown
		);
	}

	/**
	 * 表示データの初期化。
	 *
	 * @param {String} type 表示タイプ
	 */
	searchbox.Main.prototype.
	initSearchboxData = function(type) {
		var btnSearch       = aaoh.kaze.Gadget.$('btnSearch');
		var imgSearchEngine = aaoh.kaze.Gadget.$('imgSearchEngine');

		var srcBtnSearchUp   = null;
		var srcBtnSearchOver = null;
		var srcBtnSearchDown = null;
		if (!aaoh.kaze.Type.isGoogle() && !aaoh.kaze.Type.isIE()) {
			srcBtnSearchUp = 'images/searchbox' + type + '-search.png';

		} else {
			srcBtnSearchUp = 'sub-images/searchbox' + type + '-search_up.png';
		}
		srcBtnSearchOver = 'sub-images/searchbox' + type + '-search_over.png';
		srcBtnSearchDown = 'sub-images/searchbox' + type + '-search_down.png';

		aaoh.kaze.Element.setBackgroundImage(
			btnSearch, srcBtnSearchUp, srcBtnSearchOver, srcBtnSearchDown
		);

		// yahoo対応
		if (aaoh.kaze.Type.isYahoo()) {
			var btnSearchEngine = aaoh.kaze.Gadget.$('btnSearchEngine');
			var srcBtnSearchEngine
				= 'sub-images/searchbox' + type + '-allow-down.png';
			aaoh.kaze.Element.setBackgroundImage(
				btnSearchEngine, srcBtnSearchEngine
			);

		} else {
			var selSearchEngine1  = aaoh.kaze.Gadget.$('selSearchEngine_1');
			var selSearchEngine2  = aaoh.kaze.Gadget.$('selSearchEngine_2');
			var selSearchEngine3  = aaoh.kaze.Gadget.$('selSearchEngine_3');
			var selSearchEngine4  = aaoh.kaze.Gadget.$('selSearchEngine_4');
			var selSearchEngine5  = aaoh.kaze.Gadget.$('selSearchEngine_5');
			var selSearchEngine6  = aaoh.kaze.Gadget.$('selSearchEngine_6');
			var selSearchEngine7  = aaoh.kaze.Gadget.$('selSearchEngine_7');
			var selSearchEngine8  = aaoh.kaze.Gadget.$('selSearchEngine_8');
			var selSearchEngine9  = aaoh.kaze.Gadget.$('selSearchEngine_9');
			var selSearchEngine10 = aaoh.kaze.Gadget.$('selSearchEngine_10');
			aaoh.kaze.Element.setInnerValue(
				selSearchEngine1,
				aaoh.sora.App.control.SEARCH_LIST.engine['1'].dispName
			);
			aaoh.kaze.Element.setInnerValue(
				selSearchEngine2,
				aaoh.sora.App.control.SEARCH_LIST.engine['2'].dispName
			);
			aaoh.kaze.Element.setInnerValue(
				selSearchEngine3,
				aaoh.sora.App.control.SEARCH_LIST.engine['3'].dispName
			);
			aaoh.kaze.Element.setInnerValue(
				selSearchEngine4,
				aaoh.sora.App.control.SEARCH_LIST.engine['4'].dispName
			);
			aaoh.kaze.Element.setInnerValue(
				selSearchEngine5,
				aaoh.sora.App.control.SEARCH_LIST.engine['5'].dispName
			);
			aaoh.kaze.Element.setInnerValue(
				selSearchEngine6,
				aaoh.sora.App.control.SEARCH_LIST.engine['6'].dispName
			);
			aaoh.kaze.Element.setInnerValue(
				selSearchEngine7,
				aaoh.sora.App.control.SEARCH_LIST.engine['7'].dispName
			);
			aaoh.kaze.Element.setInnerValue(
				selSearchEngine8,
				aaoh.sora.App.control.SEARCH_LIST.engine['8'].dispName
			);
			aaoh.kaze.Element.setInnerValue(
				selSearchEngine9,
				aaoh.sora.App.control.SEARCH_LIST.engine['9'].dispName
			);
			aaoh.kaze.Element.setInnerValue(
				selSearchEngine10,
				aaoh.sora.App.control.SEARCH_LIST.engine['10'].dispName
			);
		}

		var borderColor = null;
		var borderImg   = null;
		switch (type) {
			default:
			case '1':
				borderColor = '#b4b4b4';
				borderImg   = 'sub-images/line-bottom.png';
				break;

			case '2':
				borderColor = '#b4b4b4';
				borderImg   = 'sub-images/line-bottom.png';
				break;

			case '3':
				borderColor = '#b4b4b4';
				borderImg   = 'sub-images/line-bottom.png';
				break;
		}

		if (aaoh.kaze.Type.isGoogle() || aaoh.kaze.Type.isYahoo()) {
			var lnRow1 = aaoh.kaze.Gadget.$('lnRow1');
			var lnRow2 = aaoh.kaze.Gadget.$('lnRow2');
			var lnCol1 = aaoh.kaze.Gadget.$('lnCol1');
			var lnCol2 = aaoh.kaze.Gadget.$('lnCol2');
			aaoh.kaze.Element.setImage(lnRow1, borderImg);
			aaoh.kaze.Element.setImage(lnRow2, borderImg);
			aaoh.kaze.Element.setImage(lnCol1, borderImg);
			aaoh.kaze.Element.setImage(lnCol2, borderImg);

		} else {
			aaoh.kaze.Element.setBorderColor(imgSearchEngine,  borderColor);
		}
	}

	/**
	 * イベントの設定。
	 */
	searchbox.Main.prototype.
	setEventListener = function() {
		// yahoo対応
		if (aaoh.kaze.Type.isYahoo()) {
			var txtSearchEngine = aaoh.kaze.Gadget.$('txtSearchEngine');
			if (txtSearchEngine != null) {
				aaoh.kaze.Element.setOnClick(txtSearchEngine, function() {
					aaoh.sora.App.main.doPopupSearchEngine();
				});
			}

			var btnSearchEngine = aaoh.kaze.Gadget.$('btnSearchEngine');
			if (btnSearchEngine != null) {
				aaoh.kaze.Element.setOnClick(btnSearchEngine, function() {
					aaoh.sora.App.main.doPopupSearchEngine();
				});
			}

			var index = aaoh.kaze.Gadget.$('index');
			if (index != null) {
				aaoh.kaze.Element.setOnKeyDown(index, function(event) {
					aaoh.sora.App.main.doInputSuggestBefore(event);
				});
				aaoh.kaze.Element.setOnKeyUp(index, function(event) {
					aaoh.sora.App.main.doInputSuggestAfter(event);
				});
			}

			widget.onLoseFocus = function(){
				aaoh.sora.App.main.clearSuggest();
				aaoh.sora.App.main.txtSearch.loseFocus();
			};

		} else {
			var imgSearchEngine = aaoh.kaze.Gadget.$('imgSearchEngine');
			if (imgSearchEngine != null) {
				aaoh.kaze.Element.setOnClick(imgSearchEngine, function() {
					aaoh.sora.App.main.setSuggestBlur();

					var selSearchEngine = aaoh.kaze.Gadget.$('selSearchEngine');
					aaoh.kaze.Element.setFocus(selSearchEngine);
				});
			}

			var selSearchEngine = aaoh.kaze.Gadget.$('selSearchEngine');
			if (selSearchEngine != null) {
				aaoh.kaze.Element.setOnChange(selSearchEngine, function() {
					aaoh.sora.App.main.setSearchEngine();
				});
			}

			var selSuggest = aaoh.kaze.Gadget.$('selSuggest');
			if (selSuggest != null) {
				aaoh.kaze.Element.setOnFocus(selSuggest, function(event) {
					aaoh.sora.App.main.setSuggestFocus(event);
				});
				aaoh.kaze.Element.setOnBlur(selSuggest, function(event) {
					aaoh.sora.App.main.setSuggestBlur(event);
				});

				aaoh.kaze.Element.setOnKeyDown(selSuggest, function(event) {
					aaoh.sora.App.main.doInputSuggestBefore(event);
				});
				aaoh.kaze.Element.setOnKeyUp(selSuggest, function(event) {
					aaoh.sora.App.main.doInputSuggestAfter(event);
				});

				if (aaoh.kaze.Type.isGoogle()) {
					aaoh.kaze.Element.setOnChange(selSuggest, function(event) {
						if (aaoh.sora.App.main.flgGSuggest) {
							aaoh.sora.App.main.flgGSuggest = false;
							return;

						} else if (selSuggest.selectedIndex < 0) {
							return;
						}

						aaoh.sora.App.main.doSuggestSelect(event);
					});

				} else {
					aaoh.kaze.Element.setOnClick(selSuggest, function(event) {
						aaoh.sora.App.main.doSuggestSelect(event);
					});
				}
			}
		}

		this.setSearchboxEventListener();
	}

	/**
	 * イベントの設定。
	 */
	searchbox.Main.prototype.
	setSearchboxEventListener = function() {
		var txtSearch = aaoh.kaze.Gadget.$('txtSearch');
		if (txtSearch != null) {
			aaoh.kaze.Element.setOnFocus(txtSearch, function() {
				aaoh.sora.App.main.setSearchFocus();
			});
			aaoh.kaze.Element.setOnBlur(txtSearch, function() {
				aaoh.sora.App.main.setSearchBlur();
			});

			aaoh.kaze.Element.setOnKeyDown(txtSearch, function(event) {
				aaoh.sora.App.main.doInputSearchBefore(event);
			});
			aaoh.kaze.Element.setOnKeyUp(txtSearch, function(event) {
				aaoh.sora.App.main.doInputSearchAfter(event);
			});
			aaoh.kaze.Element.setOnKeyPress(txtSearch, function(event) {
				aaoh.sora.App.main.doInputSearchAfter2(event);
			});
		}

		var btnSearch = aaoh.kaze.Gadget.$('btnSearch');
		if (btnSearch != null) {
			aaoh.kaze.Element.setOnClick(btnSearch, function() {
				aaoh.sora.App.main.clearSuggest();
				aaoh.sora.App.main.doSearch();
			});
		}
	}

	/**
	 * 初期化処理。
	 */
	searchbox.Main.prototype.
	init = function() {
		// 設定情報のデフォルト設定
		if (
			aaoh.kaze.Type.isMobile()
			|| !this.suggestJson.flgEnable_
		) {
			// 古いOpera対応
			aaoh.sora.App.model.data.isSuggest = false;

		// opera widget対応
		// google対応
		} else if (
			aaoh.kaze.Type.isOpera() || aaoh.kaze.Type.isGoogle()
		) {
			// キー入力監視
			this.tmpTimer.setInterval(function() {
				aaoh.sora.App.main.checkKeyInput();
			}, this.suggestTime * 2);

		// yahoo対応
		} else if (aaoh.kaze.Type.isYahoo()) {
			var selSuggest = aaoh.kaze.Gadget.$('selSuggest');

			for (var cnt = 0; cnt < this.selSuggestMaxSize; cnt++) {
				var item = new Text();
				item.id          = 'selSuggest' + (cnt + 1);
				item.width       = selSuggest.width - 5;
				item.height      = this.suggestHeight;
				item.hOffset     = 5;
				item.vOffset     = cnt * this.suggestHeight + 10;
				item.onClick     = function(event) {
					aaoh.sora.App.main.doSuggestSelect(event, this.data);
				};
				item.onGainFocus = function() {
					aaoh.sora.App.main.setSuggestFocus();
				};

				selSuggest.appendChild(item);
			}
		}

		this.setEventListener();

		// サジェスト表示のクリア
		aaoh.kaze.Element.setDisplay(this.liSuggest, false);
	}
})();
